@@ -28,7 +28,7 @@
 
 static void     close_ps_file(FILE * fp);
 static void     handle_landscape_scale(FILE * fp);
-static void     insert_ps_header(FILE * fp);
+static void     insert_ps_header(FILE * fp, bool privacy);
 static void     skip_ps_header(FILE * PSfile);
 static void     create_font_encoding(const char *fontname);
 
@@ -38,7 +38,7 @@ static char     ps_filename[256] = "gri.ps";	/* basename */
 static char     ps_filename_used[256] = "";	/* actual name used */
 static bool     user_gave_ps_filename = false;	/* did user give the name? */
 static int      which_page = 0;	/* page counter */
-
+
 bool            _no_bounding_box = false;
 
 
@@ -331,7 +331,7 @@ Cannot open output PostScript file named\n\t`%s'\nin this directory.  Do you hav
 	// write some header stuff in postscript file
 	_grWritePS = true;
 	// define postscript abbreviations
-	insert_ps_header(_grPS);
+	insert_ps_header(_grPS, true);
 	if (specifications == 1)
 		set_page_characteristics();
 }
@@ -360,14 +360,17 @@ static void set_page_characteristics()
 }
 
 static void
-insert_ps_header(FILE * fp)
+insert_ps_header(FILE * fp, bool privacy)
 {
 	/*
 	 * write conforming postscript prolog
 	 */
 	/* fprintf(fp, "%%!PS-Adobe-1.0\n"); */
 	fprintf(fp, "%%!PS-Adobe-2.0 EPSF-1.2\n");
-	fprintf(fp, "%%%%Creator: %s\n", creator_name);
+	if (privacy)
+	  fprintf(fp, "%%%%Creator: %s\n", "");
+	else
+	  fprintf(fp, "%%%%Creator: %s\n", creator_name);
 	fprintf(fp, "%%%%Title: %s\n", ps_filename_used);
 	SECOND_TYPE sec;
 	time(&sec);
@@ -716,7 +719,7 @@ gr_drawsymbol(double xcm, double ycm, gr_symbol_type symbol_name)
 		 || xcm > OFFPAGE_RIGHT
 		 || ycm < OFFPAGE_BOTTOM
 		 || ycm > OFFPAGE_TOP)) {
-		warning("Drawing a symbol at a location which is offpage.");
+		warning("Drawing a symbol at a location that is offpage.");
 	}
 	switch (symbol_name) {
 	case gr_plus_symbol:
@@ -939,16 +942,6 @@ gr_error(const char *lab)
 void
 abort_gri()
 {
-	gr_textput("\
-             Suggestion: in unix system with `gdb' command, type\n");
-	gr_textput("\
-                         gdb gri core\n");
-	gr_textput("\
-                         where\n");
-	gr_textput("\
-                         quit\n");
-	gr_textput("\
-             to get a traceback for use in a bug report.\n\n");
 	abort();
 }
 
@@ -1011,17 +1004,25 @@ gr_hsv2rgb(double h, double s, double v, double *r, double *g, double *b)
 bool
 gr_missing(double x)
 {
+        //printf("gr_missing(%lf) ... ",x);
 	if (_grMissingValueUsed) {
+	        //printf("GRI MISSING VALUE USED ... ");
 		if (_grMissingValue == 0.0)	// ignore tolerance if 0
 			return (x == 0.0);
-		if (x == _grMissingValue)	// speed up (?)
+		if (x == _grMissingValue) {	// speed up (?)
+		        //printf("GRI MISSING VALUE was exact match\n");
 			return true;
+		}
 		x = GRI_ABS(x - _grMissingValue);
-		if (x < _grMissingValue_tolerance)
+		if (x < _grMissingValue_tolerance) {
+		        //printf("GRI MISSING VALUE was match within tolerance\n");
 			return true;
-		else
+		} else {
+		        //printf("GRI MISSING VALUE no  match within tolerance\n");
 			return false;
+		}
 	} else {
+	        //printf("GRI MISSING VALUE no missing value used\n");
 		return false;
 	}
 }
@@ -1117,7 +1118,31 @@ gr_record_scale()
 		_grTransform_x, _grxl_pt, _grxl, _grPtPerUser_x,
 		_grTransform_y, _gryb_pt, _gryb, _grPtPerUser_y);
 }
-
+
+// rgb values each in range 0 to 1; result in same range
+void
+gr_rgb2cmyk(double R[], double G[], double B[], 
+	unsigned int n,
+	double c[], double m[], double y[], double k[])
+{
+	double Cp, Mp, Yp;
+	for( unsigned int i = 0; i < n; i += 1 ) {
+		Cp = 1.0 - R[i];
+		Mp = 1.0 - G[i];
+		Yp = 1.0 - B[i];
+		k[i] = Cp; if (Mp < k[i]) k[i] = Mp; if (Yp < k[i]) k[i] = Yp; // min
+		if (k[i] == 1.0) {
+			c[i] = 0.0;
+			m[i] = 0.0;
+			y[i] = 0.0;
+		} else {
+			c[i] = (Cp - k[i]) / (1.0 - k[i]);
+			m[i] = (Mp - k[i]) / (1.0 - k[i]);
+			y[i] = (Yp - k[i]) / (1.0 - k[i]);
+		}
+	}
+}
+
 /*
  * (red, green, blue) in range from 0 to 1 is translated to (hue, saturation,
  * brightness) in same range.
@@ -1244,13 +1269,13 @@ gr_save_postscript(const char *PS_name, int normal_scale)
 		_grMagy = 1.0;
 		_grOriginx = 0.0;
 		_grOriginy = 0.0;
-		insert_ps_header(PS_file);
+		insert_ps_header(PS_file, true);
 		_grMagx = old_grMagx;
 		_grMagy = old_grMagy;
 		_grOriginx = old_grOriginx;
 		_grOriginy = old_grOriginy;
 	} else
-		insert_ps_header(PS_file);
+		insert_ps_header(PS_file, true);
 	while (!feof(_grPS)) {
 		fgets(grTempString, _grTempStringLEN, _grPS);
 		if (feof(_grPS))
@@ -1308,6 +1333,7 @@ gr_set_missing_value(double x)
 void
 gr_set_missing_value_none()
 {
+        //printf("%s:%d TURNING OFF missing value.\n",__FILE__,__LINE__);
 	_grMissingValueUsed = false;
 }
 
