@@ -74,9 +74,10 @@ extern char     _grTempString[];
 bool            display_colors();
 static void     create_builtin_colors(void);
 bool            _no_startup_message = false;
-bool            _contour_label_rotated = false;   // <-> draw.c set.c
-bool            _contour_label_whiteunder = true; // <-> draw.c set.c
-bool            _store_cmds_in_ps = true;	  // <-> read.c
+bool            _contour_label_rotated = false;   	// <-> draw.c set.c
+bool            _contour_label_whiteunder = true;	// <-> draw.c set.c
+bool            _store_cmds_in_ps = true;	  		// <-> read.c
+bool 			_private = true; 					// "-private" and "-no_private" commandline options
 
 bool            initialize_image(); 
 bool            initialize_imageMask(); 
@@ -98,9 +99,9 @@ int             last_optional_arg = 0;
 bool
 look_up_color(const char *name, double *red, double *green, double *blue)
 {
-	int             i = 0, num = colorStack.size();
+	int i, num = colorStack.size();
 	for (i = 0; i < num; i++) {
-		if (!strcmp(name, colorStack[i].getName())) {
+		if (!strcmp(name, colorStack[i].get_name().c_str())) {
 			*red   = colorStack[i].getR();
 			*green = colorStack[i].getG();
 			*blue  = colorStack[i].getB();
@@ -158,6 +159,10 @@ start_up(int argc, char **argv)
 	for (int i = 0; i < argc; i++) printf("DEBUG:                     '%s'\n", argv[i]);
 #endif
 */
+#ifdef OSX_BUNDLE
+//	printf("%s:%d OSX_BUNDLE being used\n",__FILE__,__LINE__);
+#endif
+
 	_output_file_type = postscript;
 	// Record version number
 	int major_version, minor_version, minor_minor_version;
@@ -195,7 +200,18 @@ start_up(int argc, char **argv)
 	PUT_VAR("..ylast..", 0.0);
 	PUT_VAR("..image_width..", 0.0);
 	PUT_VAR("..image_height..", 0.0);
-	
+
+#ifdef OSX_BUNDLE
+        extern std::string _lib_directory;
+        _lib_directory.assign(argv[0]);
+	std::string::size_type last_slash = _lib_directory.rfind("/");
+        if (last_slash != STRING_NPOS) {
+		_lib_directory.STRINGERASE(last_slash, _lib_directory.length());
+        } else {
+		fatal_err("OSX error: cannot find slash in argv[0]\n");
+        }
+//        printf("%s:%d: OSX_BUNDLE using _lib_directory '%s'\n", __FILE__, __LINE__, _lib_directory.c_str());
+#endif
 	// Get leftover (non-optional) arguments
 	argv_leftover = interpret_optional_arguments(argc, argv);
 	unsigned int argc_leftover = 0;
@@ -265,23 +281,24 @@ first argument looks like a PostScript filename.  Older versions\n\
 	gr_begin(1);
 
 	// Embed info on how gri was invoked.
-	extern FILE *_grPS;
-	char host[BUFSIZ];
+	if (!_private) {
+		extern FILE *_grPS;
+		char host[BUFSIZ];
 #if defined(HAVE_GETHOSTNAME)
-	if (0 != gethostname(host, BUFSIZ - 1))
-		strcpy(host, "unknown");
+		if (0 != gethostname(host, BUFSIZ - 1))
+			strcpy(host, "unknown");
 #else
-	strcpy(host, "unknown");
+		strcpy(host, "unknown");
 #endif
-	fprintf(_grPS, "%%gri:# Gri was invoked by user named\n%%gri:#     %s\n%%gri:# on host named\n%%gri:#     %s\n%%gri:# using the command\n%%gri:#   ",  egetenv("USER"), host);
-	for (int i = 0; i < argc; i++)
-		fprintf(_grPS, " %s", argv[i]);
-	SECOND_TYPE sec;
-	time(&sec);
-	sprintf(_grTempString, "%s", asctime(localtime(&sec)));
-	_grTempString[-1 + strlen(_grTempString)] = '\0'; // trim newline
-	fprintf(_grPS, "\n%%gri:# at local time %s.\n", _grTempString);
-
+		fprintf(_grPS, "%%gri:# Gri was invoked by user named\n%%gri:#     %s\n%%gri:# on host named\n%%gri:#     %s\n%%gri:# using the command\n%%gri:#   ",  egetenv("USER"), host);
+		for (int i = 0; i < argc; i++)
+			fprintf(_grPS, " %s", argv[i]);
+		SECOND_TYPE sec;
+		time(&sec);
+		sprintf(_grTempString, "%s", asctime(localtime(&sec)));
+		_grTempString[-1 + strlen(_grTempString)] = '\0'; // trim newline
+		fprintf(_grPS, "\n%%gri:# at local time %s.\n", _grTempString);
+	}
 	put_syn("\\.ps_file.", gr_currentPSfilename(), true);
 	// Disable tracing during startup phase, unless in superuser mode.
 	double          trace_old;
@@ -317,7 +334,7 @@ first argument looks like a PostScript filename.  Older versions\n\
 
 	// DataFile stack
 	DataFile new_data_file;
-	if (superuser() & FLAG_AUT1)printf("\nDEBUG: %s:%d pushing back a datafile at address %x\n",__FILE__,__LINE__,int(&new_data_file));
+	if (superuser() & FLAG_AUT1)printf("\nDEBUG: %s:%d pushing back a datafile at address %lx\n",__FILE__,__LINE__,(long unsigned int)(&new_data_file));
 	_dataFILE.push_back(new_data_file);
 
 	_first = true;
@@ -368,7 +385,7 @@ display_colors()
 	char msg[200];
 	for (unsigned int i = 0; i < colorStack.size(); i++) {
 		sprintf(msg, "Color `%s' has RGB = (%f,%f,%f)\n",
-			colorStack[i].getName(),
+			colorStack[i].get_name().c_str(),
 			colorStack[i].getR(),
 			colorStack[i].getG(),
 			colorStack[i].getB());
@@ -675,6 +692,8 @@ interpret_optional_arguments(int argc, char *argv[])
 		{ "no_cmd_in_ps",      '\0', POPT_ARG_NONE   | POPT_ARGFLAG_ONEDASH, NULL, FLAG_NO_CMD_IN_PS     },
 		{ "no_startup_message",'\0', POPT_ARG_NONE   | POPT_ARGFLAG_ONEDASH, NULL, FLAG_NO_STARTUP_MESSAGE},
 		{ "no_warn_offpage",   '\0', POPT_ARG_NONE   | POPT_ARGFLAG_ONEDASH, NULL, FLAG_NO_WARN_OFFPAGE  },
+		{ "private",           '\0', POPT_ARG_NONE   | POPT_ARGFLAG_ONEDASH, NULL, FLAG_PRIVATE          },
+		{ "no_private",        '\0', POPT_ARG_NONE   | POPT_ARGFLAG_ONEDASH, NULL, FLAG_NO_PRIVATE       },
 		{ "publication",       '\0', POPT_ARG_NONE   | POPT_ARGFLAG_ONEDASH, NULL, FLAG_PUBLICATION      },
 		{ "superuser",         '\0', POPT_ARG_STRING | POPT_ARGFLAG_ONEDASH, NULL, FLAG_SUPERUSER        },
 		{ "trace",             't',  POPT_ARG_NONE   | POPT_ARGFLAG_ONEDASH, NULL, 't'                   },
@@ -695,7 +714,12 @@ interpret_optional_arguments(int argc, char *argv[])
 	poptReadDefaultConfig(optCon, 0); // for aliasing ... this seems broken though
 	int arg;
 	extern char _gri_number[];
+#ifndef OSX_BUNDLE
 	_lib_directory.assign(DEFAULT_GRI_DIR);
+#endif
+#ifdef OSX_BUNDLE
+	printf("%s:%d _lib_directory is '%s'\n",__FILE__,__LINE__,_lib_directory.c_str());
+#endif
 	while ((arg = poptGetNextOpt(optCon)) > 0) {
 		const char *optArg = poptGetOptArg(optCon);
 		int ival;
@@ -802,6 +826,12 @@ interpret_optional_arguments(int argc, char *argv[])
 		case FLAG_NO_WARN_OFFPAGE:
 			_warn_offpage = false;
 			break;
+		case FLAG_PRIVATE:
+			_private = true;
+			break;
+		case FLAG_NO_PRIVATE:
+			_private = false;
+			break;
 		case FLAG_PUBLICATION:
 			PUT_VAR("..publication..", 1.0);
 			break;
@@ -861,7 +891,12 @@ interpret_optional_arguments(int argc, char *argv[])
 	// BUG: REMOVE THIS (LONG) BLOCK WHEN POPT IS FINALLY WORKING!
 	extern char     _gri_number[];
 	int             number_optional_arg = 0;
+#ifndef OSX_BUNDLE
 	_lib_directory.assign(DEFAULT_GRI_DIR);
+#endif
+#ifdef OSX_BUNDLE
+	//printf("%s:%d _lib_directory is '%s'\n",__FILE__,__LINE__,_lib_directory.c_str());
+#endif
 	// Interpret optional [-] arguments if they exist.
 	if (argc > 1) {
 		int             i;
@@ -969,6 +1004,10 @@ interpret_optional_arguments(int argc, char *argv[])
 				} else if (!strcmp(argv[i], "-h") || !strcmp(argv[i], "-help")) {
 					give_help();
 					gri_exit(0);
+				} else if (!strcmp(argv[i], "-private")) {
+					_private = true;
+				} else if (!strcmp(argv[i], "-no_private")) {
+					_private = false;
 				} else if (!strcmp(argv[i], "-p") || !strcmp(argv[i], "-publication")) {
 					PUT_VAR("..publication..", 1.0);
 				} else if (!strncmp(argv[i], "-c", 2)) {
@@ -1046,7 +1085,7 @@ give_help()
         gr_textput("     gri - draw scientific graphs\n");
         gr_textput("\n");
         gr_textput("SYNOPSIS\n");
-        gr_textput("     gri [OPTIONS] [command_file [postscript_file]]\n");
+        gr_textput("     gri [OPTIONS] [command_file [optional_arguments]]\n");
         gr_textput("\n");
         gr_textput("DESCRIPTION\n");
         gr_textput("     If a command file (command_file) is named, commands are read from that file;\n");
@@ -1056,7 +1095,10 @@ give_help()
         gr_textput("\n");
         gr_textput("     There are 3 special forms that do no graphing:\n");
         gr_textput("       `gri -creator postscript_file'\n");
-        gr_textput("         Extracts the Gri commands that created the Gri PostScript file.\n");
+        gr_textput("         Extracts the Gri commands that created the Gri PostScript file,\n");
+		gr_textput("         but only if the Gri invocation that created the PostScript file\n");
+		gr_textput("         had used the -no_private commandline option, or if the version of\n");
+		gr_textput("         Gri that produced the file was earlier than 2.12.10.\n");
         gr_textput("       `gri -help' or `gri -h'\n");
         gr_textput("         Prints this help message.\n");
         gr_textput("       `gri -version' or `gri -v'\n");
@@ -1086,22 +1128,41 @@ give_help()
 
         gr_textput("     -no_bounding_box\n");
         gr_textput("             Make bounding-box be full page.\n");
+
         gr_textput("     -no_expecting\n");
         gr_textput("             Prevent warning message if `expecting version .n.'\n");
         gr_textput("             command is missing.\n");
+
         gr_textput("     -no_startup_message\n");
         gr_textput("             Stops printing of startup message.\n");
+
         gr_textput("     -output file_name\n");
         gr_textput("             Specify the name of the file to hold the graphical output.  If\n");
         gr_textput("             this flag is not specified, the file will be PostScript,\n");
-	gr_textput("             and its name will be derived from the name of the\n");
-	gr_textput("             commandfile, e.g. `mygraph.gri'\n");
+		gr_textput("             and its name will be derived from the name of the\n");
+		gr_textput("             commandfile, e.g. `mygraph.gri'\n");
         gr_textput("             will produce `mygraph.ps'), or, for interactive use,\n");
         gr_textput("             it will have a name like `gri-00.ps', or\n");
         gr_textput("             `gri-01.ps' if the former file exists, etc.\n");
+
+       	gr_textput("     -private\n");
+		gr_textput("             Prevents inserting any information about the user into\n");
+	  	gr_textput("             the PostScript file (see -no_private, next).  As of\n");
+	    gr_textput("             version 2.12.10, this privacy option is assumed by default.\n");
+
+       	gr_textput("     -no_private\n");
+  		gr_textput("             Instructs Gri to include comments in the PostScript file that\n"); 
+		gr_textput("             identify the user, state the commandline arguments used in\n"); 
+		gr_textput("             invoking Gri, and that list all the commands that were executed.\n"); 
+		gr_textput("             This information can be recovered by calling Gri on the\n"); 
+		gr_textput("             PostScript file, with the -creator commandline argument.\n"); 
+		gr_textput("             Until version 2.12.10, the default was to include this \n"); 
+		gr_textput("             information, but a change was made out of privacy concerns.\n"); 
+
         gr_textput("     -publication or -p\n");
         gr_textput("             Sets the builtin variable ..publication.. to 1; normally it is 0.\n");
         gr_textput("             One might use if statements (`if !..publication..' ...) on drafts.\n");
+
         gr_textput("     -superuser\n");
         gr_textput("             Used mainly by Gri programmers (who can check the value with the\n");
         gr_textput("             C function `superuser()'.)  An optional value can be supplied\n");
@@ -1143,7 +1204,10 @@ insert_creator_name_in_PS(int argc, char *argv[], const std::string& psname)
 	gr_setup_creatorname(_gri_number);
 	gr_setup_creatorname(" (released ");
 	gr_setup_creatorname(_gri_release_time);
-	gr_setup_creatorname(").  User=");
+	if (_private)
+		gr_setup_creatorname(")");
+	else
+		gr_setup_creatorname(").  User=");
 	if (egetenv("USER"))
 		gr_setup_creatorname(egetenv("USER"));
 #if 0				// SF bug 711354
